#!/bin/bash
set -x

# use plars' lifeboat scripts to get our adb serial
rm -rf lifeboat
git clone $LIFEBOAT_BRANCH lifeboat
export ANDROID_SERIAL=$(./lifeboat/get-device-info serial $NODE_NAME)

rm -rf $WORKSPACE/results
mkdir $WORKSPACE/results
export OUTPUTDIR="$WORKSPACE/results"

rm -rf qa-jenkins-jobs
bzr branch $QA_JENKINS_JOBS_BRANCH qa-jenkins-jobs

export UBUNTU_SYSTEM_TESTS_CONFIG_BRANCH="lp:ubuntu-system-tests-config"
export CONFIG_PATH=${WORKSPACE}/ubuntu-system-tests.conf
./qa-jenkins-jobs/scripts/ubuntu-system-tests/write-ust-config.sh
cat >> $CONFIG_PATH <<EOF
device_serial = $ANDROID_SERIAL
output_dir = $OUTPUTDIR
EOF
cat $CONFIG_PATH

# let's work in a virtualenv
rm -rf ve3
virtualenv --system-site-packages --python=python3 ve3
. ve3/bin/activate

export https_proxy=https://squid.internal:3128/

rm -rf ubuntu-system-tests
bzr branch $UBUNTU_SYSTEM_TESTS_BRANCH ubuntu-system-tests
cd ubuntu-system-tests
python3 setup.py develop

query_practitest_for_tests_to_run_by_filter () {
    python3 -m ubuntu_system_tests.run list --filters filter:$1 --config=$CONFIG_PATH
}

case "$TESTS_TO_RUN" in
    # yes we magically know the filter numbers
    "sanity")
	TESTS_TO_RUN=$(query_practitest_for_tests_to_run_by_filter 63805)
	;;
    "regression")
	TESTS_TO_RUN=$(query_practitest_for_tests_to_run_by_filter 117776)
	;;
    "stable")
	TESTS_TO_RUN=$(query_practitest_for_tests_to_run_by_filter 126345)
	;;
    "unstable")
	TESTS_TO_RUN=$(query_practitest_for_tests_to_run_by_filter 126346)
	;;
    "")
	# NOTE that conditional build step should've prevented
	echo "Please specify tests to run!" >&2
	exit 1
	;;
esac

# Jenkins param is a long string, transform to multi-line to do remaining_tests math
INITIAL_TESTS_TO_RUN=$(echo "$TESTS_TO_RUN" | tr ' ' '\n');

initial_tests_to_run () {
    printf "$INITIAL_TESTS_TO_RUN" | sort | uniq;
}

successfully_run_tests () {
    # a test has been run successfully when it has generated a subunit result file
    find $OUTPUTDIR -name "*.subunit" -exec basename {} .subunit \; | sort | uniq;
}

remaining_tests () {
    # find the difference between tests we've successfully run and the initial list
    comm -13 <(successfully_run_tests) <(initial_tests_to_run);
}

run_tests () {
    #./qa-jenkins-jobs/scripts/ubuntu-system-tests/run-ubuntu-system-tests.sh "$1"
    # setup device
    python3 -m ubuntu_system_tests.run setup -n -d -p -u -v --config=$CONFIG_PATH
    # run tests
    python3 -m ubuntu_system_tests.run run -n -v --config=$CONFIG_PATH "$1"
}

RETRY=0;
until [ $(remaining_tests | wc -l) == 0 ] || [ $RETRY -ge $MAX_RETRIES ]; do
    RETRY=$(($RETRY+1));
    # need to switch back to spaces instead of newlines
    TESTS_TO_RUN="$(echo $(remaining_tests) | tr '\n' ' ')";
    echo "Trial number $RETRY with tests $TESTS_TO_RUN";
    run_tests "$(echo "$TESTS_TO_RUN")"
done;

deactivate # our virtualenv
