#!/usr/bin/python
import argparse
import requests
import sys
from launchpadlib.launchpad import Launchpad

MP_URL_PREFIX = 'https://code.launchpad.net/'
LAUNCHPAD_API_PREFIX = 'https://api.launchpad.net/1.0/'


def main(mp_url):
    if mp_url.startswith('lp'):
        # Login to launchpad anonymously
        launchpad = Launchpad.login_anonymously('ci job', 'production')

        # Get the branch
        branch = launchpad.branches.getByUrl(url=mp_url)

        if branch is not None:
            # Get the merge proposal data
            mp = requests.get(
                branch.landing_targets_collection_link).json()['entries'][0]
        else:
            raise ValueError("The url provided did not returned any "
                             "data from launchpad")
    elif mp_url.startswith('http'):
        url = mp_url.replace(MP_URL_PREFIX, LAUNCHPAD_API_PREFIX)
        mp = requests.get(url).json()
    else:
        raise ValueError("Please provide a valid url")

    change_description = mp['description']
    try:
        tests = change_description.split('@run_tests:')[1:][0].strip()
    except IndexError:
        tests = ""
    sys.stdout.write(str(tests))

if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description='This script will get the list of tests '
                    'to be run from the mp commit message')
    parser.add_argument('-mpu', '--merge_proposal_url',
                        help='Merge proposal url', required=True)
    args = parser.parse_args()
    main(args.merge_proposal_url)
